@@ -139,7 +139,7 @@ void cm_BkgDaemon(void * parm)
 #ifdef DEBUG_REFCOUNT
             osi_Log2(afsd_logp,"cm_BkgDaemon (before) scp 0x%x ref %d",rp->scp, rp->scp->refCount);
 #endif
-            code = (*rp->procp)(rp->scp, rp->p1, rp->p2, rp->p3, rp->p4, rp->userp);
+            code = (*rp->procp)(rp->scp, rp->p1, rp->p2, rp->p3, rp->p4, rp->userp, &rp->req);
 #ifdef DEBUG_REFCOUNT
             osi_Log2(afsd_logp,"cm_BkgDaemon (after) scp 0x%x ref %d",rp->scp, rp->scp->refCount);
 #endif
@@ -170,11 +170,12 @@ void cm_BkgDaemon(void * parm)
             } /* otherwise fall through */
         case 0:  /* success */
         default: /* other error */
-            if (code == 0)
+            if (code == 0) {
                 osi_Log1(afsd_logp,"cm_BkgDaemon SUCCESS: request 0x%p", rp);
-            else
+            } else {
                 osi_Log2(afsd_logp,"cm_BkgDaemon FAILED: request dropped 0x%p code 0x%x",
                          rp, code);
+            }
             cm_ReleaseUser(rp->userp);
             cm_ReleaseSCache(rp->scp);
             free(rp);
@@ -186,7 +187,7 @@ void cm_BkgDaemon(void * parm)
 }
 
 void cm_QueueBKGRequest(cm_scache_t *scp, cm_bkgProc_t *procp, afs_uint32 p1, afs_uint32 p2, afs_uint32 p3, afs_uint32 p4,
-	cm_user_t *userp)
+	cm_user_t *userp, cm_req_t *reqp)
 {
     cm_bkgRequest_t *rp;
 
@@ -202,6 +203,7 @@ void cm_QueueBKGRequest(cm_scache_t *scp, cm_bkgProc_t *procp, afs_uint32 p1, af
     rp->p2 = p2;
     rp->p3 = p3;
     rp->p4 = p4;
+    rp->req = *reqp;
 
     lock_ObtainWrite(&cm_daemonLock);
     cm_bkgQueueCount++;
@@ -426,7 +428,8 @@ void cm_Daemon(long parm)
     lastDownServerCheck = now - cm_daemonCheckDownInterval/2 + (rand() % cm_daemonCheckDownInterval);
     lastUpServerCheck = now - cm_daemonCheckUpInterval/2 + (rand() % cm_daemonCheckUpInterval);
     lastTokenCacheCheck = now - cm_daemonTokenCheckInterval/2 + (rand() % cm_daemonTokenCheckInterval);
-    lastBusyVolCheck = now - cm_daemonCheckOfflineVolInterval/2 * (rand() % cm_daemonCheckOfflineVolInterval);
+    if (cm_daemonCheckOfflineVolInterval)
+        lastBusyVolCheck = now - cm_daemonCheckOfflineVolInterval/2 * (rand() % cm_daemonCheckOfflineVolInterval);
     if (cm_daemonPerformanceTuningInterval)
         lastPerformanceCheck = now - cm_daemonPerformanceTuningInterval/2 * (rand() % cm_daemonPerformanceTuningInterval);
     lastServerRankCheck = now - cm_daemonRankServerInterval/2 * (rand() % cm_daemonRankServerInterval);
@@ -550,7 +553,8 @@ void cm_Daemon(long parm)
             now = osi_Time();
         }
 
-        if ((bAddrChangeCheck || now > lastBusyVolCheck + cm_daemonCheckOfflineVolInterval) &&
+        if ((bAddrChangeCheck || (cm_daemonCheckOfflineVolInterval &&
+                                  now > lastBusyVolCheck + cm_daemonCheckOfflineVolInterval)) &&
             daemon_ShutdownFlag == 0 &&
             powerStateSuspended == 0) {
             lastBusyVolCheck = now;
